<?php

/**
 * 'Certification' entity view callback.
 */
function certification_view($certification) {
  drupal_set_title(entity_label('certification', $certification));
  return entity_view('certification', array(entity_id('certification', $certification) => $certification), 'full');
}

/**
 * Certification page callback
 */
function certification_content() {
  // we are going to output the results in a table with a nice header
  $header = array(
    array('data' => t('Certification Rule')),
    array('data' => t('Certified User')),
    array('data' => t('Authorized By')),
    array('data' => t('Operations')),
  );

  $query = new EntityFieldQuery();
  $query->entityCondition('entity_rule', 'certification')
    ->entityCondition('entity_type', 'certification')
    ->pager(15)
    ->addMetaData('account', user_load(1)); // Run the query as user 1.
  $result = $query->execute();

  $rows = array();
  if (isset($result['certification'])) {
    $cert_ids = array_keys($result['certification']);
    $certs = entity_load('certification', $cert_ids);
     $display = array(
      'label' => 'hidden',
      'settings' => array(
        'link' => 1,
      ),
    );

    foreach ( $certs as $entity ) {
      // Create tabular rows for our entities.
      $rows[] = array(
        'data' => array(
          //'title' => t("<a href='/certification-rule/{$entity->cert_rule_id}'>$entity->cert_rule_name</a>"),
          'title' => render(field_view_field('certification', $entity, 'field_certified_rule_ref', $display)),
          'Certified User' => render(field_view_field('certification', $entity, 'field_certified_user', $display)),
          'Authorized By' => render(field_view_field('certification', $entity, 'field_certified_auth_user', $display)),
          'operations' => "<ul class='links inline'>
                            <li class='edit first'><a href='/certification/{$entity->cert_id}/view'>view</a></li>
                            <li class='delete last'><a href='/certification/{$entity->cert_id}/edit'>edit</a></li>
                          </ul>",
        ),
      );
    }
  }
  // Create a render array ($build) which will be themed as a table with a
  // pager.
  $build['pager_table'] = array(
    '#theme' => 'table',
    '#header' => $header,
    '#rows' => $rows,
    '#empty' => t('There are no certification types found in the db'),
  );

  // attach the pager theme
  $build['pager_pager'] = array('#theme' => 'pager');

  return $build;
}



/**
 * Certification Type edit (new) form.
 */
function certification_form($form, &$form_state, $certification) {
  $form_state['certification'] = $certification;

  $form['cert_id'] = array(
    '#type' => 'hidden',
    '#title' => t('cert_id'),
    '#default_value' => $certification->cert_id,
  );


  field_attach_form('certification', $certification, $form, $form_state);

  $submit = array();
  if (!empty($form['#submit'])) {
    $submit += $form['#submit'];
  }

  $form['actions'] = array(
    '#weight' => 100,
  );

  $form['actions']['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save Certification'),
    '#submit' => $submit + array('certification_form_submit'),
  );

  // Show Delete button if we edit certification_rule.
  $certification_id = entity_id('certification' ,$certification);
  if (!empty($certification_id) && certification_access('edit', $certification)) {
    $form['actions']['delete'] = array(
      '#type' => 'submit',
      '#value' => t('Delete'),
      '#submit' => array('certification_form_submit_delete'),
    );
  }

  $form['#validate'][] = 'certification_form_validate';

  return $form;
}
/**
 * Certification type submit validation handler.
 */
function certification_form_validate($form, &$form_state) {

}

/**
 * Certification type submit handler.
 */
function certification_form_submit($form, &$form_state) {
  $certification = $form_state['certification'];
  entity_form_submit_build_entity('certification', $certification, $form, $form_state);
  certification_save($certification);
  $certification_uri = entity_uri('certification', $certification);
  $form_state['redirect'] = $certification_uri['path'];
  drupal_set_message(t('Certification %title saved.', array('%title' => entity_label('certification', $certification))));
}


/**
 * Certification type submit delete handler.
 */
function certification_form_submit_delete($form, &$form_state) {
  $certification = $form_state['certification'];
  $certification_uri = entity_uri('certification', $certification);
  $form_state['redirect'] = $certification_uri['path'] . '/delete';
}

/**
 * Delete confirmation form.
 */
function certification_delete_form($form, &$form_state, $certification) {
  $form_state['certification'] = $certification;
  $certification_uri = entity_uri('certification', $certification);
  //$return = confirm_form();
  return confirm_form($form,
    t('Are you sure you want to delete %title?', array('%title' => entity_label('certification', $certification))),
    $certification_uri['path'],
    t('This action cannot be undone.'),
    t('Delete'),
    t('Cancel')
  );
}

/**
 * Delete form submit handler.
 */
function certification_delete_form_submit($form, &$form_state) {
  $certification = $form_state['certification'];
  certification_delete($certification);
  drupal_set_message(t('Certification %title deleted.', array('%title' => entity_label('certification', $certification))));
  $form_state['redirect'] = '<front>';
}
