<?php

/**
 * 'Certification type' view callback.
 */
function certification_rule_view($certification_rule) {
  drupal_set_title(entity_label('certification_rule', $certification_rule));
  return entity_view('certification_rule', array(entity_id('certification_rule', $certification_rule) => $certification_rule), 'full');
}

/**
 * Provide view of certification_rules that appears as a content tab like comments
 */
function certification_rule_content() {
  // we are going to output the results in a table with a nice header
  $header = array(
    array('data' => t('Title')),
    array('data' => t('CiviGroup')),
    array('data' => t('CiviEvent Type')),
    array('data' => t('Operations')),
  );

  $query = new EntityFieldQuery();
  $query->entityCondition('entity_type', 'certification_rule')
    ->entityCondition('entity_type', 'certification_rule')
    ->pager(15)
    ->addMetaData('account', user_load(1)); // Run the query as user 1.
  $result = $query->execute();

  $rows = array();
  if (isset($result['certification_rule'])) {
    $cert_rule_ids = array_keys($result['certification_rule']);
    $cert_rules = entity_load('certification_rule', $cert_rule_ids);
    $display = array(
      'label' => 'hidden',
      'module' => 'list',
      'settings' => array(),
      'type' => 'list_default',
      'weight' => '4',
    );

    foreach ( $cert_rules as $entity ) {
      // Create tabular rows for our entities.
      $rows[] = array(
        'data' => array(
          //'title' => t("<a href='/certification-rule/{$entity->cert_rule_id}'>$entity->cert_rule_name</a>"),
          'title' => l($entity->cert_rule_name, 'certification-rule/' . $entity->cert_rule_id),
          'civigroup' => render(field_view_field('certification_rule', $entity, 'field_cert_rule_civigroup', $display)),
          'civievent' => render(field_view_field('certification_rule', $entity, 'field_cert_rule_civievent', $display)),
          'edit' => l('edit', 'certification-rule/' . $entity->cert_rule_id . '/edit'),
        ),
      );
    }
  }
  // Create a render array ($build) which will be themed as a table with a
  // pager.
  $build['pager_table'] = array(
    '#theme' => 'table',
    '#header' => $header,
    '#rows' => $rows,
    '#empty' => t('There are no certification types found in the db'),
  );

  // attach the pager theme
  $build['pager_pager'] = array('#theme' => 'pager');

  return $build;
}

/**
 * Certification Type edit (new) form.
 */
function certification_rule_form($form, &$form_state, $certification_rule) {
  $form_state['certification_rule'] = $certification_rule;

  $form['cert_rule_id'] = array(
    '#type' => 'hidden',
    '#title' => t('cert_rule_id'),
    '#default_value' => $certification_rule->cert_rule_id,
  );
  $form['cert_rule_name'] = array(
    '#type' => 'textfield',
    '#title' => t('Name'),
    '#default_value' => $certification_rule->cert_rule_name,
    '#required' => TRUE,
  );



  field_attach_form('certification_rule', $certification_rule, $form, $form_state);

  $submit = array();
  if (!empty($form['#submit'])) {
    $submit += $form['#submit'];
  }

  $form['actions'] = array(
    '#weight' => 100,
  );

  $form['actions']['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save Certification Type'),
    '#submit' => $submit + array('certification_rule_form_submit'),
  );

  // Show Delete button if we edit certification_rule.
  $certification_rule_id = entity_id('certification_rule' ,$certification_rule);
  if (!empty($certification_rule_id) && certification_rule_access('edit', $certification_rule)) {
    $form['actions']['delete'] = array(
      '#type' => 'submit',
      '#value' => t('Delete'),
      '#submit' => array('certification_rule_form_submit_delete'),
    );
  }

  $form['#validate'][] = 'certification_rule_form_validate';

  return $form;
}
/**
 * Certification type submit validation handler.
 */
function certification_rule_form_validate($form, &$form_state) {

}

/**
 * Certification type submit handler.
 */
function certification_rule_form_submit($form, &$form_state) {
  $certification_rule = $form_state['certification_rule'];
  entity_form_submit_build_entity('certification_rule', $certification_rule, $form, $form_state);
  certification_rule_save($certification_rule);
  $certification_rule_uri = entity_uri('certification_rule', $certification_rule);
  $form_state['redirect'] = $certification_rule_uri['path'];
  drupal_set_message(t('Certification type %title saved.', array('%title' => entity_label('certification_rule', $certification_rule))));
}


/**
 * Certification type submit delete handler.
 */
function certification_rule_form_submit_delete($form, &$form_state) {
  $certification_rule = $form_state['certification_rule'];
  $certification_rule_uri = entity_uri('certification_rule', $certification_rule);
  $form_state['redirect'] = $certification_rule_uri['path'] . '/delete';
}

/**
 * Delete confirmation form.
 */
function certification_rule_delete_form($form, &$form_state, $certification_rule) {
  $form_state['certification_rule'] = $certification_rule;
  $certification_rule_uri = entity_uri('certification_rule', $certification_rule);
  //$return = confirm_form();
  return confirm_form($form,
    t('Are you sure you want to delete %title?', array('%title' => entity_label('certification_rule', $certification_rule))),
    $certification_rule_uri['path'],
    t('This action cannot be undone.'),
    t('Delete'),
    t('Cancel')
  );
}

/**
 * Delete form submit handler.
 */
function certification_rule_delete_form_submit($form, &$form_state) {
  $certification_rule = $form_state['certification_rule'];
  certification_rule_delete($certification_rule);
  drupal_set_message(t('Certification type %title deleted.', array('%title' => entity_label('certification_rule', $certification_rule))));
  $form_state['redirect'] = '<front>';
}

/**
 * Sync confirmation form.
 */
function certification_rule_sync_form($form, &$form_state, $certification_rule) {
  $form_state['certification_rule'] = $certification_rule;
  $certification_rule_uri = entity_uri('certification_rule', $certification_rule);
  //$return = confirm_form();
  return confirm_form($form,
    t('Sync %title?', array('%title' => entity_label('certification_rule', $certification_rule))),
    $certification_rule_uri['path'],
    t('This action cannot be undone.'),
    t('Sync'),
    t('Cancel')
  );
}

/**
 *
 * */
function certification_rule_sync_form_submit($form, &$form_state) {
  $certification_rule = $form_state['certification_rule'];
  certification_rule_sync($certification_rule);
  //$form_state['redirect'] = '<front>'; // TODO: should we go to the front page?
}
